fix_YARP_DEPRECATED_API {#master}
-----------------------

## Libraries

### `conf`

* The `YARP_DEPRECATED_API` and `YARP_DEPRECATED_API_MSG` defines are now
  deprecated in favour of `YARP_DEPRECATED_EXPORT`, `YARP_DEPRECATED_IMPORT`,
  `YARP_DEPRECATED_MSG_EXPORT`, and `YARP_DEPRECATED_MSG_IMPORT`.
